@@ -1,5 +1,5 @@
 import sqlalchemy as sa
-from six import PY3
+from sqlalchemy_continuum import get_versioning_manager
 from tests import TestCase
 
 
@@ -35,24 +35,20 @@ class ChangeSetBaseTestCase(TestCase):
 
 class ChangeSetTestCase(ChangeSetBaseTestCase):
     def test_changeset_for_history_that_does_not_have_first_insert(self):
-        tx_log_class = self.Article.__versioned__['transaction_log']
+        tx_log_class = get_versioning_manager(self.Article).transaction_cls
         tx_log = tx_log_class(issued_at=sa.func.now())
         self.session.add(tx_log)
         self.session.commit()
 
         self.session.execute(
-            '''INSERT INTO article_history
+            '''INSERT INTO article_version
             (id, %s, name, content, operation_type)
             VALUES
             (1, %d, 'something', 'some content', 1)
             ''' % (self.transaction_column_name, tx_log.id)
         )
 
-        assert self.session.query(self.ArticleHistory).first().changeset == {}
-
-
-class TestChangeSetWithTrackPropertyModifications(ChangeSetBaseTestCase):
-    track_property_modifications = True
+        assert self.session.query(self.ArticleVersion).first().changeset == {}
 
 
 class TestChangeSetWithValidityStrategy(ChangeSetTestCase):
