@@ -1,4 +1,5 @@
 import sqlalchemy as sa
+from sqlalchemy_continuum import version_class
 from tests import TestCase
 
 
@@ -28,7 +29,7 @@ class TestValidityStrategy(TestCase):
         self.Article = Article
 
     def test_schema_contains_end_transaction_id(self):
-        table = self.Article.__versioned__['class'].__table__
+        table = version_class(self.Article).__table__
         assert 'end_transaction_id' in table.c
         table.c.end_transaction_id
         assert table.c.end_transaction_id.nullable
@@ -53,13 +54,76 @@ class TestValidityStrategy(TestCase):
         )
 
 
+# class TestSomething(TestCase):
+#     def create_models(self):
+#         class TextItem(self.Model):
+#             __tablename__ = 'text_item'
+#             __versioned__ = {
+#                 'base_classes': (self.Model, ),
+#                 'strategy': 'validity',
+#             }
+#             id = sa.Column(sa.Integer, autoincrement=True, primary_key=True)
+#             tx_id = sa.Column(sa.Integer, primary_key=True)
+
+#             discriminator = sa.Column(
+#                 sa.Unicode(100)
+#             )
+#             title = sa.Column(sa.String)
+
+#             __mapper_args__ = {
+#                 'polymorphic_on': discriminator,
+#             }
+
+#         articles = sa.Table(
+#             'article',
+#             self.Model.metadata,
+#             sa.Column(
+#                 'id',
+#                 sa.Integer,
+#                 sa.ForeignKey(TextItem.id),
+#                 primary_key=True
+#             ),
+#             sa.Column(
+#                 'tx_id',
+#                 sa.Integer,
+#                 primary_key=True
+#             ),
+#             sa.Column('title', sa.String)
+#         )
+
+#         from sqlalchemy.orm import column_property
+
+#         class Article(TextItem):
+#             __table__ = articles
+#             __mapper_args__ = {
+#                 'polymorphic_identity': u'article',
+#             }
+#             tx_id = column_property(
+#                 articles.c.tx_id, TextItem.__table__.c.tx_id
+#             )
+#             title = column_property(
+#                 articles.c.title, TextItem.__table__.c.title
+#             )
+#         self.TextItem = TextItem
+#         self.Article = Article
+
+#     def test_something(self):
+#         self.session.add(self.Article(id=1, tx_id=1, title='mjoo'))
+#         self.session.commit()
+
+#         self.session.execute("UPDATE text_item SET title = 'asdsadas'")
+
+#         article = self.session.query(self.Article).first()
+#         print article.title
+
+
 class TestJoinTableInheritanceWithValidityVersioning(TestCase):
     def create_models(self):
         class TextItem(self.Model):
             __tablename__ = 'text_item'
             __versioned__ = {
                 'base_classes': (self.Model, ),
-                'strategy': 'validity'
+                'strategy': 'validity',
             }
             id = sa.Column(sa.Integer, autoincrement=True, primary_key=True)
 
@@ -95,11 +159,11 @@ class TestJoinTableInheritanceWithValidityVersioning(TestCase):
 
     def setup_method(self, method):
         TestCase.setup_method(self, method)
-        self.TextItemHistory = self.TextItem.__versioned__['class']
-        self.ArticleHistory = self.Article.__versioned__['class']
-        self.BlogPostHistory = self.BlogPost.__versioned__['class']
+        self.TextItemVersion = version_class(self.TextItem)
+        self.ArticleVersion = version_class(self.Article)
+        self.BlogPostVersion = version_class(self.BlogPost)
 
     def test_all_tables_contain_transaction_id_column(self):
-        assert 'end_transaction_id' in self.TextItemHistory.__table__.c
-        assert 'end_transaction_id' in self.ArticleHistory.__table__.c
-        assert 'end_transaction_id' in self.BlogPostHistory.__table__.c
+        assert 'end_transaction_id' in self.TextItemVersion.__table__.c
+        assert 'end_transaction_id' in self.ArticleVersion.__table__.c
+        assert 'end_transaction_id' in self.BlogPostVersion.__table__.c
